plib3.ui To Do List
===================

Planned Features
----------------

- Add more widgets (possibles are date and time edit, edit with spinner,
  color picker, font picker, clock, progress bar, slider)
